Class: Projects::Model::Folder

Inherits:
Object
  • Object
show all
Defined in:
lib/projects/model/Folder.rb

Overview

  • This class is used to make an object for Folder.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#isDiscussionObject

  • Get the folder is in discussion or not.

Returns

  • true, if thew folder is in discussion else false.


69
70
71
# File 'lib/projects/model/Folder.rb', line 69

def isDiscussion
  @isDiscussion
end

Instance Method Details

#getIdObject

  • Get the folder id.

Returns

  • Folder id.


29
30
31
# File 'lib/projects/model/Folder.rb', line 29

def getId
	return @id
end

#getNameObject

  • Get the folder name.

Returns

  • Folder name.


49
50
51
# File 'lib/projects/model/Folder.rb', line 49

def getName
	return @name
end

#getURLObject

  • Get the folder URL.

Returns

  • Folder URL.


89
90
91
# File 'lib/projects/model/Folder.rb', line 89

def getURL
	return @url
end

#setId(id) ⇒ Object

  • Set the folder id.

Parameters

* id
  • ID of the folder.


19
20
21
# File 'lib/projects/model/Folder.rb', line 19

def setId(id)
	@id = id
end

#setIsDicussion(isDiscussion) ⇒ Object

  • Set the folder is in discussion or not.

Parameters

* isDiscussion
  • Is the folder is in discussion or not.


59
60
61
# File 'lib/projects/model/Folder.rb', line 59

def setIsDicussion(isDiscussion)
	@isDiscussion = isDiscussion
end

#setName(name) ⇒ Object

  • Set the folder name.

Parameters

* name
  • Name of the folder.


39
40
41
# File 'lib/projects/model/Folder.rb', line 39

def setName(name)
	@name = name
end

#setURL(url) ⇒ Object

  • Set the folder URL.

Parameters

* url
  • URL for the folder.


79
80
81
# File 'lib/projects/model/Folder.rb', line 79

def setURL(url)
	@url = url
end

#toParamMAPObject

  • Convert the Folder object into HashMap.

Returns

  • HashMap object.


99
100
101
102
103
104
105
106
107
# File 'lib/projects/model/Folder.rb', line 99

def toParamMAP
	requestBody = Hash.new
	
	if name != nil
		requestBody["name"] = name
	end
	
	return requestBody
end