Class: Projects::Model::Log

Inherits:
Object
  • Object
show all
Defined in:
lib/projects/model/Log.rb

Overview

  • This class is used to make an object for Log.

Direct Known Subclasses

Buglog, Generallog, Tasklog

Instance Method Summary collapse

Instance Method Details

#getBillStatus ⇒ Object

  • Get the bill status for the log.

Returns

  • Bill status.


189
190
191
# File 'lib/projects/model/Log.rb', line 189

def getBillStatus
	return @billStatus
end

#getDate ⇒ Object

  • Get the log date.

Returns

  • Log date.


329
330
331
# File 'lib/projects/model/Log.rb', line 329

def getDate
	return @logDate
end

#getHours ⇒ Object

  • Get the hours for the log.

Returns

  • Log hours.


69
70
71
# File 'lib/projects/model/Log.rb', line 69

def getHours
	return @hours
end

#getHoursDisplay ⇒ Object

  • Get the hour display format.

Returns

  • Hour display format.


109
110
111
# File 'lib/projects/model/Log.rb', line 109

def getHoursDisplay
	return @hoursDisplay
end

#getId ⇒ Object

  • Get the log id.

Returns

  • Log id.


29
30
31
# File 'lib/projects/model/Log.rb', line 29

def getId
	return @id
end

#getLogDate ⇒ Object

  • Get the log date.

Returns

  • Log date.


269
270
271
# File 'lib/projects/model/Log.rb', line 269

def getLogDate
	return @logDate
end

#getLogDateFormat ⇒ Object

  • Get the log date format.

Returns

  • Log date format.


289
290
291
# File 'lib/projects/model/Log.rb', line 289

def getLogDateFormat
	return @logDateFormat
end

#getLogDateLong ⇒ Object

  • Get the log date.

Returns

  • Log date.


309
310
311
# File 'lib/projects/model/Log.rb', line 309

def getLogDateLong
	return @logDateLong
end

#getMinutes ⇒ Object

  • Get the minutes for the log.

Returns

  • Log minutes.


89
90
91
# File 'lib/projects/model/Log.rb', line 89

def getMinutes
	return @minutes
end

#getNotes ⇒ Object

  • Get the log notes.

Returns

  • Log notes.


49
50
51
# File 'lib/projects/model/Log.rb', line 49

def getNotes
	return @notes
end

#getOwnerId ⇒ Object

  • Get the owner id.

Returns

  • Owner id.


149
150
151
# File 'lib/projects/model/Log.rb', line 149

def getOwnerId
	return @ownerId
end

#getOwnerName ⇒ Object

  • Get the owner name.

Returns

  • Owner name.


169
170
171
# File 'lib/projects/model/Log.rb', line 169

def getOwnerName
	return @ownerName
end

#getProjectId ⇒ Object

  • Get the project id.

Returns

  • Project id.


209
210
211
# File 'lib/projects/model/Log.rb', line 209

def getProjectId
	return @projectId
end

#getProjectName ⇒ Object

  • Get the project name.

Returns

  • Project name.


229
230
231
# File 'lib/projects/model/Log.rb', line 229

def getProjectName
	return @projectName
end

#getTotalMinutes ⇒ Object

  • Get the total time in minutes for the log.

Returns

  • Total time in minutes for the log.


129
130
131
# File 'lib/projects/model/Log.rb', line 129

def getTotalMinutes
	return @totalMinutes
end

#getURL ⇒ Object

  • Get the URL.

Returns

  • Log URL.


249
250
251
# File 'lib/projects/model/Log.rb', line 249

def getURL
	return @url
end

#setBillStatus(billStatus) ⇒ Object

  • Set the bill status for the log.

Parameters

* billStatus
  • Bill status for the log.


179
180
181
# File 'lib/projects/model/Log.rb', line 179

def setBillStatus(billStatus)
	@billStatus = billStatus
end

#setDate(date) ⇒ Object

  • Set the log date.

Parameters

* date
  • Date for the log.


319
320
321
# File 'lib/projects/model/Log.rb', line 319

def setDate(date)
	@logDate = date
end

#setHours(hours) ⇒ Object

  • Set the hours for the log.

Parameters

* hours
  • Hours for the log.


59
60
61
# File 'lib/projects/model/Log.rb', line 59

def setHours(hours)
	@hours = hours
end

#setHoursDisplay(hoursDisplay) ⇒ Object

  • Set the hour display format.

Parameters

* hourDisplay
  • Hour display format.


99
100
101
# File 'lib/projects/model/Log.rb', line 99

def setHoursDisplay(hoursDisplay)
	@hoursDisplay = hoursDisplay
end

#setId(id) ⇒ Object

  • Set the log id.

Parameters

* id
  • ID of the log.


19
20
21
# File 'lib/projects/model/Log.rb', line 19

def setId(id)
	@id = id
end

#setLogDate(logDate) ⇒ Object

  • Set the log date.

Parameters

* logDate
  • Date of the log.


259
260
261
# File 'lib/projects/model/Log.rb', line 259

def setLogDate(logDate)
	@logDate = logDate
end

#setLogDateFormat(logDateFormat) ⇒ Object

  • Set the log date format.

Parameters

* logDate
  • Date format of the log.


279
280
281
# File 'lib/projects/model/Log.rb', line 279

def setLogDateFormat(logDateFormat)
	@logDateFormat = logDateFormat
end

#setLogDateLong(logDateLong) ⇒ Object

  • Set the log date.

Parameters

* logDateLong
  • Date for the log.


299
300
301
# File 'lib/projects/model/Log.rb', line 299

def setLogDateLong(logDateLong)
	@logDateLong = logDateLong
end

#setMinutes(minutes) ⇒ Object

  • Set the minutes for the log.

Parameters

* minutes
  • Minutes for the log.


79
80
81
# File 'lib/projects/model/Log.rb', line 79

def setMinutes(minutes)
	@minutes = minutes
end

#setNotes(notes) ⇒ Object

  • Set the notes for the log.

Parameters

* notes
  • Notes for the log.


39
40
41
# File 'lib/projects/model/Log.rb', line 39

def setNotes(notes)
	@notes = notes
end

#setOwnerId(ownerId) ⇒ Object

  • Set the owner id.

Parameters

* ownerId
  • ID of the owner.


139
140
141
# File 'lib/projects/model/Log.rb', line 139

def setOwnerId(ownerId)
	@ownerId = ownerId
end

#setOwnerName(ownerName) ⇒ Object

  • Set the owner name.

Parameters

* ownerName
  • Name of the owner.


159
160
161
# File 'lib/projects/model/Log.rb', line 159

def setOwnerName(ownerName)
	@ownerName = ownerName
end

#setProjectId(projectId) ⇒ Object

  • Set the project id.

Parameters

* projectId
  • ID of the project.


199
200
201
# File 'lib/projects/model/Log.rb', line 199

def setProjectId(projectId)
	@projectId = projectId
end

#setProjectName(projectName) ⇒ Object

  • Set the project name.

Parameters

* projectName
  • Name of the project.


219
220
221
# File 'lib/projects/model/Log.rb', line 219

def setProjectName(projectName)
	@projectName = projectName
end

#setTotalMinutes(totalMinutes) ⇒ Object

  • Set the total time in minutes for the log.

Parameters

* totalMinutes
  • Total time in minutes for the log.


119
120
121
# File 'lib/projects/model/Log.rb', line 119

def setTotalMinutes(totalMinutes)
	@totalMinutes = totalMinutes
end

#setURL(url) ⇒ Object

  • Set the URL for the log.

Parameters

* url
  • URL for the log.


239
240
241
# File 'lib/projects/model/Log.rb', line 239

def setURL(url)
	@url = url
end

#toParamMAP ⇒ Object

  • Convert the Log object into HashMap.

Returns

  • HashMap object.


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/projects/model/Log.rb', line 339

def toParamMAP
	requestBody = Hash.new
	
	if logDate != nil
		requestBody["date"] = logDate
	end
	if billStatus != nil
		requestBody["bill_status"] = billStatus
	end
	if hours != nil
		requestBody["hours"] = hours
	end
	if notes != nil
		requestBody["notes"] = notes
	end
	
	return requestBody
end