Class: Projects::Model::Portal

Inherits:
Object
  • Object
show all
Defined in:
lib/projects/model/Portal.rb

Overview

  • This class is used to make an object for Portal.

Instance Method Summary collapse

Instance Method Details

#getCode ⇒ Object

  • Get the language code.

Returns

  • Language code.


208
209
210
# File 'lib/projects/model/Portal.rb', line 208

def getCode
	return @code
end

#getCompanyName ⇒ Object

  • Get the company name.

Returns

  • Company name.


128
129
130
# File 'lib/projects/model/Portal.rb', line 128

def getCompanyName
	return @companyName
end

#getCountry ⇒ Object

  • Get the country.

Returns

  • Country name.


248
249
250
# File 'lib/projects/model/Portal.rb', line 248

def getCountry
	return @country
end

#getDateFormat ⇒ Object

  • Get the date format.

Returns

  • Date format of the portal.


188
189
190
# File 'lib/projects/model/Portal.rb', line 188

def getDateFormat
	return @dateFormat
end

#getGmtTimeZone ⇒ Object

  • Get the gmt time zone.

Returns

  • gmt time zone.


88
89
90
# File 'lib/projects/model/Portal.rb', line 88

def getGmtTimeZone
	return @gmtTimeZone
end

#getId ⇒ Object

  • Get the portal id.

Returns

  • Portal id.


28
29
30
# File 'lib/projects/model/Portal.rb', line 28

def getId
	return @id
end

#getLanguage ⇒ Object

  • Get the language.

Returns

  • Language of the portal.


228
229
230
# File 'lib/projects/model/Portal.rb', line 228

def getLanguage
	return @language
end

#getName ⇒ Object

  • Get the portal name.

Returns

  • Portal name.


48
49
50
# File 'lib/projects/model/Portal.rb', line 48

def getName 
	return @name
end

#getProjectURL ⇒ Object

  • Get the project URL.

Returns

  • Project URL.


268
269
270
# File 'lib/projects/model/Portal.rb', line 268

def getProjectURL
	return @projectUrl
end

#getRole ⇒ Object

  • Get the role.

Returns

  • Role of the person.


108
109
110
# File 'lib/projects/model/Portal.rb', line 108

def getRole
	return @role
end

#getTimeZone ⇒ Object

  • Get the time zone.

Returns

  • Time zone for the portal.


168
169
170
# File 'lib/projects/model/Portal.rb', line 168

def getTimeZone
	return @timeZone
end

#getWebsiteURL ⇒ Object

  • Get the Website URL.

Returns

  • Website URL.


148
149
150
# File 'lib/projects/model/Portal.rb', line 148

def getWebsiteURL
	return @websiteUrl
end

#isDefault ⇒ Object

  • Get whether portal is default portal or not.

Returns

  • true, if the portal is a default portal else false.


68
69
70
# File 'lib/projects/model/Portal.rb', line 68

def isDefault 
	return @isDefault
end

#setCode(code) ⇒ Object

  • Set the language code.

Parameters

* code
  • Code of the language.


198
199
200
# File 'lib/projects/model/Portal.rb', line 198

def setCode(code)
	@code =code
end

#setCompanyName(companyName) ⇒ Object

  • Set the company name.

Parameters

* companyName
  • Name of the company.


118
119
120
# File 'lib/projects/model/Portal.rb', line 118

def setCompanyName(companyName)
	@companyName = companyName
end

#setCountry(country) ⇒ Object

  • Set the country.

Parameters

* country
  • Country for portal.


238
239
240
# File 'lib/projects/model/Portal.rb', line 238

def setCountry(country)
	@country = country
end

#setDateFormat(dateFormat) ⇒ Object

  • Set the date format.

Parameters

* dateFormat
  • Date format for the portal.


178
179
180
# File 'lib/projects/model/Portal.rb', line 178

def setDateFormat(dateFormat)
	@dateFormat = dateFormat
end

#setDefault(isDefault) ⇒ Object

  • Set whether portal is default portal or not.

Parameters

* isDefault
  • Is this postal default portal or not.


58
59
60
# File 'lib/projects/model/Portal.rb', line 58

def setDefault(isDefault)
	@isDefault = isDefault
end

#setGmtTimeZone(gmtTimeZone) ⇒ Object

  • Set the gmt time zone.

Parameters

* gmtTimeZone
  • Gmt time zone for the portal.


78
79
80
# File 'lib/projects/model/Portal.rb', line 78

def setGmtTimeZone(gmtTimeZone)
	@gmtTimeZone = gmtTimeZone
end

#setId(id) ⇒ Object

  • Set the portal id.

Parameters

* id
  • ID of the portal.


18
19
20
# File 'lib/projects/model/Portal.rb', line 18

def setId(id)
	@id = id
end

#setLanguage(language) ⇒ Object

  • Set the language.

Parameters

* language
  • Language for the portal.


218
219
220
# File 'lib/projects/model/Portal.rb', line 218

def setLanguage(language)
	@language = language
end

#setName(name) ⇒ Object

  • Set the portal name.

Parameters

* name
  • Name of the portal.


38
39
40
# File 'lib/projects/model/Portal.rb', line 38

def setName(name)
	@name = name
end

#setProjectURL(projectUrl) ⇒ Object

  • Set the project URL.

Parameters

* projectUrl
  • URL for the project.


258
259
260
# File 'lib/projects/model/Portal.rb', line 258

def setProjectURL(projectUrl)
	@projectUrl = projectUrl
end

#setRole(role) ⇒ Object

  • Set the role.

Parameters

* role
  • Role of the person.


98
99
100
# File 'lib/projects/model/Portal.rb', line 98

def setRole(role) 
	@role = role
end

#setTimeZone(timeZone) ⇒ Object

  • Set the time zone.

Parameters

* timeZone
  • Time zone for the portal.


158
159
160
# File 'lib/projects/model/Portal.rb', line 158

def setTimeZone(timeZone)
	@timeZone = timeZone
end

#setWebsiteURL(websiteUrl) ⇒ Object

  • Set the WEBsite URL.

Parameters

* websiteUrl
  • URL for the Website.


138
139
140
# File 'lib/projects/model/Portal.rb', line 138

def setWebsiteURL(websiteUrl)
	@websiteUrl = websiteUrl
end