Class: Projects::Model::Project
- Inherits:
-
Object
- Object
- Projects::Model::Project
- Defined in:
- lib/projects/model/Project.rb
Overview
- This class is used to make an object for Project.
Instance Method Summary collapse
-
#getActivityURL ⇒ Object
- Get the activity URL.
-
#getBugURL ⇒ Object
- Get the bug URL.
-
#getClosedBugCount ⇒ Object
- Get the closed bug count.
-
#getClosedMilestoneCount ⇒ Object
- Get the closed milestone count.
-
#getClosedTaskCount ⇒ Object
- Get the closed task count.
-
#getCreatedDate ⇒ Object
- Get the project created date.
-
#getCreatedDateFormat ⇒ Object
- Get the created date format for the project.
-
#getCreatedDateLong ⇒ Object
- Get the project created date long.
-
#getDescription ⇒ Object
- Get the project description.
-
#getDocumentURL ⇒ Object
- Get the document URL.
-
#getEventURL ⇒ Object
- Get the event URL.
-
#getFolderURL ⇒ Object
- Get the folder URL.
-
#getForumURL ⇒ Object
- Get the forum URL.
-
#getId ⇒ Object
- Set the project id.
-
#getMilestoneURL ⇒ Object
- Get the milestone URL.
-
#getName ⇒ Object
- Get the project name.
-
#getOpenBugCount ⇒ Object
- Get the open bug count.
-
#getOpenMilestoneCount ⇒ Object
- Get the open milestone count.
-
#getOpenTaskCount ⇒ Object
- Get the open task count.
-
#getOwnerId ⇒ Object
- Get the owner id.
-
#getOwnerName ⇒ Object
- Get the owner name.
-
#getStatus ⇒ Object
- Get the project status.
-
#getStatusURL ⇒ Object
- Get the status URL.
-
#getTasklistURL ⇒ Object
- Get the task list URL.
-
#getTaskURL ⇒ Object
- Get the task URL.
-
#getTimesheetURL ⇒ Object
- Get the time sheet URL.
-
#getURL ⇒ Object
- Get the project URL.
-
#getUserURL ⇒ Object
- Get the user URL.
-
#setActivityURL(activityUrl) ⇒ Object
- Set the activity URL.
-
#setBugURL(bugUrl) ⇒ Object
- Set the bug URL.
-
#setClosedBugCount(closedBugCount) ⇒ Object
- Set the closed bug count.
-
#setClosedMilestoneCount(closedMilestoneCount) ⇒ Object
- Set the closed milestone count.
-
#setClosedTaskCount(closedTaskCount) ⇒ Object
- Set the closed task count.
-
#setCreatedDate(createdDate) ⇒ Object
- Set the date when the project is being created.
-
#setCreatedDateFormat(createdDateFormat) ⇒ Object
- Set the created date format for the project.
-
#setCreatedDateLong(createdDateLong) ⇒ Object
- Set the project created date.
-
#setDescription(description) ⇒ Object
- Set the project description.
-
#setDocumentURL(documentUrl) ⇒ Object
- Set the document URL.
-
#setEventURL(eventUrl) ⇒ Object
- Set the event URL.
-
#setFolderURL(folderUrl) ⇒ Object
- Set the folder URL.
-
#setForumURL(forumUrl) ⇒ Object
- Set the forum URL.
-
#setId(id) ⇒ Object
- Get the project id.
-
#setMilestoneURL(milestoneUrl) ⇒ Object
- Set the milestone URL.
-
#setName(name) ⇒ Object
- Set the project name.
-
#setOpenBugCount(openBugCount) ⇒ Object
- Set the open bug count.
-
#setOpenMilestoneCount(openMilestoneCount) ⇒ Object
- Set the open milestone count.
-
#setOpenTaskCount(openTaskCount) ⇒ Object
- Set the open task count.
-
#setOwnerId(ownerId) ⇒ Object
- Set the owner id.
-
#setOwnerName(ownerName) ⇒ Object
- Set the owner name.
-
#setStatus(status) ⇒ Object
- Set the status of the project.
-
#setStatusURL(statusUrl) ⇒ Object
- Set the status URL.
-
#setTasklistURL(tasklistUrl) ⇒ Object
- Set the task list URL.
-
#setTaskURL(taskUrl) ⇒ Object
- Set the task URL.
-
#setTimesheetURL(timesheetUrl) ⇒ Object
- Set the time sheet URL.
-
#setURL(url) ⇒ Object
- Set the project URL.
-
#setUserURL(userUrl) ⇒ Object
- Set the user URL.
-
#toParamMAP ⇒ Object
- Convert the Project object into HashMap.
Instance Method Details
#getActivityURL ⇒ Object
- Get the activity URL.
Returns
- Activity URL.
348 349 350 |
# File 'lib/projects/model/Project.rb', line 348 def getActivityURL return @activityUrl end |
#getBugURL ⇒ Object
- Get the bug URL.
Returns
- bug URL.
428 429 430 |
# File 'lib/projects/model/Project.rb', line 428 def getBugURL return @bugUrl end |
#getClosedBugCount ⇒ Object
- Get the closed bug count.
Returns
- Closed bug count for the project.
308 309 310 |
# File 'lib/projects/model/Project.rb', line 308 def getClosedBugCount return @closedBugCount end |
#getClosedMilestoneCount ⇒ Object
- Get the closed milestone count.
Returns
- closed milestone count for the project.
268 269 270 |
# File 'lib/projects/model/Project.rb', line 268 def getClosedMilestoneCount return @closedMilestoneCount end |
#getClosedTaskCount ⇒ Object
- Get the closed task count.
Returns
- Closed task count for the project.
228 229 230 |
# File 'lib/projects/model/Project.rb', line 228 def getClosedTaskCount return @closedTaskCount end |
#getCreatedDate ⇒ Object
- Get the project created date.
Returns
- Project created date.
88 89 90 |
# File 'lib/projects/model/Project.rb', line 88 def getCreatedDate return @createdDate end |
#getCreatedDateFormat ⇒ Object
- Get the created date format for the project.
Returns
- Project created date format.
108 109 110 |
# File 'lib/projects/model/Project.rb', line 108 def getCreatedDateFormat return @createdDateFormat end |
#getCreatedDateLong ⇒ Object
- Get the project created date long.
Returns
- project created date long.
128 129 130 |
# File 'lib/projects/model/Project.rb', line 128 def getCreatedDateLong return @createdDateLong end |
#getDescription ⇒ Object
- Get the project description.
Returns
- Project description.
148 149 150 |
# File 'lib/projects/model/Project.rb', line 148 def getDescription return @description end |
#getDocumentURL ⇒ Object
- Get the document URL.
Returns
- Document URL.
508 509 510 |
# File 'lib/projects/model/Project.rb', line 508 def getDocumentURL return @documentUrl end |
#getEventURL ⇒ Object
- Get the event URL.
Returns
- Event URL.
488 489 490 |
# File 'lib/projects/model/Project.rb', line 488 def getEventURL return @eventUrl end |
#getFolderURL ⇒ Object
- Get the folder URL.
Returns
- Folder URL.
528 529 530 |
# File 'lib/projects/model/Project.rb', line 528 def getFolderURL return @folderUrl end |
#getForumURL ⇒ Object
- Get the forum URL.
Returns
- Forum URL.
548 549 550 |
# File 'lib/projects/model/Project.rb', line 548 def getForumURL return @forumUrl end |
#getId ⇒ Object
- Set the project id.
Parameters
- * id
- ID of the project.
18 19 20 |
# File 'lib/projects/model/Project.rb', line 18 def getId return @id end |
#getMilestoneURL ⇒ Object
- Get the milestone URL.
Returns
- milestone URL.
368 369 370 |
# File 'lib/projects/model/Project.rb', line 368 def getMilestoneURL return @milestoneUrl end |
#getName ⇒ Object
- Get the project name.
Returns
- Project name.
48 49 50 |
# File 'lib/projects/model/Project.rb', line 48 def getName return @name end |
#getOpenBugCount ⇒ Object
- Get the open bug count.
Returns
- Open bug count for the project.
288 289 290 |
# File 'lib/projects/model/Project.rb', line 288 def getOpenBugCount return @openBugCount end |
#getOpenMilestoneCount ⇒ Object
- Get the open milestone count.
Returns
- Open milestone count for the project.
248 249 250 |
# File 'lib/projects/model/Project.rb', line 248 def getOpenMilestoneCount return @openMilestoneCount end |
#getOpenTaskCount ⇒ Object
- Get the open task count.
Returns
- Open task count for the project.
208 209 210 |
# File 'lib/projects/model/Project.rb', line 208 def getOpenTaskCount return @openTaskCount end |
#getOwnerId ⇒ Object
- Get the owner id.
Returns
- Owner id.
188 189 190 |
# File 'lib/projects/model/Project.rb', line 188 def getOwnerId return @ownerId end |
#getOwnerName ⇒ Object
- Get the owner name.
Returns
- The owner name.
168 169 170 |
# File 'lib/projects/model/Project.rb', line 168 def getOwnerName return @ownerName end |
#getStatus ⇒ Object
- Get the project status.
Returns
- Project status.
68 69 70 |
# File 'lib/projects/model/Project.rb', line 68 def getStatus return @status end |
#getStatusURL ⇒ Object
- Get the status URL.
Returns
- Status URL.
468 469 470 |
# File 'lib/projects/model/Project.rb', line 468 def getStatusURL return @statusUrl end |
#getTasklistURL ⇒ Object
- Get the task list URL.
Returns
- Task list URL.
388 389 390 |
# File 'lib/projects/model/Project.rb', line 388 def getTasklistURL return @tasklistUrl end |
#getTaskURL ⇒ Object
- Get the task URL.
Returns
- task URL.
408 409 410 |
# File 'lib/projects/model/Project.rb', line 408 def getTaskURL return @taskUrl end |
#getTimesheetURL ⇒ Object
- Get the time sheet URL.
Returns
- Time sheet URL.
448 449 450 |
# File 'lib/projects/model/Project.rb', line 448 def getTimesheetURL return @timesheetUrl end |
#getURL ⇒ Object
- Get the project URL.
Returns
- Project URL.
328 329 330 |
# File 'lib/projects/model/Project.rb', line 328 def getURL return @url end |
#getUserURL ⇒ Object
- Get the user URL.
Returns
- user URL.
568 569 570 |
# File 'lib/projects/model/Project.rb', line 568 def getUserURL return @userUrl end |
#setActivityURL(activityUrl) ⇒ Object
- Set the activity URL.
Parameters
- * activityUrl
- URL for the activity.
338 339 340 |
# File 'lib/projects/model/Project.rb', line 338 def setActivityURL(activityUrl) @activityUrl = activityUrl end |
#setBugURL(bugUrl) ⇒ Object
- Set the bug URL.
Parameters
- * bugUrl
- URL for the bug.
418 419 420 |
# File 'lib/projects/model/Project.rb', line 418 def setBugURL(bugUrl) @bugUrl = bugUrl end |
#setClosedBugCount(closedBugCount) ⇒ Object
- Set the closed bug count.
Parameters
- * closedBugCount
- Closed bug count for the project.
298 299 300 |
# File 'lib/projects/model/Project.rb', line 298 def setClosedBugCount(closedBugCount) @closedBugCount = closedBugCount end |
#setClosedMilestoneCount(closedMilestoneCount) ⇒ Object
- Set the closed milestone count.
Parameters
- * closedMilestoneCount
- Closed milestone count for the project.
258 259 260 |
# File 'lib/projects/model/Project.rb', line 258 def setClosedMilestoneCount(closedMilestoneCount) @closedMilestoneCount = closedMilestoneCount end |
#setClosedTaskCount(closedTaskCount) ⇒ Object
- Set the closed task count.
Parameters
- * closedTaskCount
- Closed task count for the project.
218 219 220 |
# File 'lib/projects/model/Project.rb', line 218 def setClosedTaskCount(closedTaskCount) @closedTaskCount = closedTaskCount end |
#setCreatedDate(createdDate) ⇒ Object
- Set the date when the project is being created.
Parameters
- * createdDate
- Created date for the project.
78 79 80 |
# File 'lib/projects/model/Project.rb', line 78 def setCreatedDate(createdDate) @createdDate = createdDate end |
#setCreatedDateFormat(createdDateFormat) ⇒ Object
- Set the created date format for the project.
Parameters
- * createdDate
- Project created date format.
98 99 100 |
# File 'lib/projects/model/Project.rb', line 98 def setCreatedDateFormat(createdDateFormat) @createdDateFormat = createdDateFormat end |
#setCreatedDateLong(createdDateLong) ⇒ Object
- Set the project created date.
Parameters
- * createdDateLong
- Project created date.
118 119 120 |
# File 'lib/projects/model/Project.rb', line 118 def setCreatedDateLong(createdDateLong) @createdDateLong = createdDateLong end |
#setDescription(description) ⇒ Object
- Set the project description.
Parameters
- * description
- Description of the project.
138 139 140 |
# File 'lib/projects/model/Project.rb', line 138 def setDescription(description) @description = description end |
#setDocumentURL(documentUrl) ⇒ Object
- Set the document URL.
Parameters
- * documentUrl
- URL for the document.
498 499 500 |
# File 'lib/projects/model/Project.rb', line 498 def setDocumentURL(documentUrl) @documentUrl = documentUrl end |
#setEventURL(eventUrl) ⇒ Object
- Set the event URL.
Parameters
- * eventUrl
- URL for the event.
478 479 480 |
# File 'lib/projects/model/Project.rb', line 478 def setEventURL(eventUrl) @eventUrl = eventUrl end |
#setFolderURL(folderUrl) ⇒ Object
- Set the folder URL.
Parameters
- * folderUrl
- URL for the folder.
518 519 520 |
# File 'lib/projects/model/Project.rb', line 518 def setFolderURL(folderUrl) @folderUrl = folderUrl end |
#setForumURL(forumUrl) ⇒ Object
- Set the forum URL.
Parameters
- * forumUrl
- URL for the forum.
538 539 540 |
# File 'lib/projects/model/Project.rb', line 538 def setForumURL(forumUrl) @forumUrl = forumUrl end |
#setId(id) ⇒ Object
- Get the project id.
Returns
- Project id.
28 29 30 |
# File 'lib/projects/model/Project.rb', line 28 def setId(id) @id = id end |
#setMilestoneURL(milestoneUrl) ⇒ Object
- Set the milestone URL.
Parameters
- * milestoneUrl
- URL for the milestone.
358 359 360 |
# File 'lib/projects/model/Project.rb', line 358 def setMilestoneURL(milestoneUrl) @milestoneUrl = milestoneUrl end |
#setName(name) ⇒ Object
- Set the project name.
Parameters
- * name
- Name of the project.
38 39 40 |
# File 'lib/projects/model/Project.rb', line 38 def setName(name) @name = name end |
#setOpenBugCount(openBugCount) ⇒ Object
- Set the open bug count.
Parameters
- * openBugCount
- Open bug count for the project.
278 279 280 |
# File 'lib/projects/model/Project.rb', line 278 def setOpenBugCount(openBugCount) @openBugCount = openBugCount end |
#setOpenMilestoneCount(openMilestoneCount) ⇒ Object
- Set the open milestone count.
Parameters
- * openMilestoneCount
- Open milestone count for the project.
238 239 240 |
# File 'lib/projects/model/Project.rb', line 238 def setOpenMilestoneCount(openMilestoneCount) @openMilestoneCount = openMilestoneCount end |
#setOpenTaskCount(openTaskCount) ⇒ Object
- Set the open task count.
Parameters
- * openTaskCount
- Open task count for the project.
198 199 200 |
# File 'lib/projects/model/Project.rb', line 198 def setOpenTaskCount(openTaskCount) @openTaskCount = openTaskCount end |
#setOwnerId(ownerId) ⇒ Object
- Set the owner id.
Parameters
- * ownerId
- ID of the owner.
178 179 180 |
# File 'lib/projects/model/Project.rb', line 178 def setOwnerId(ownerId) @ownerId = ownerId end |
#setOwnerName(ownerName) ⇒ Object
- Set the owner name.
Parameters
- * ownerName
- Name of the owner.
158 159 160 |
# File 'lib/projects/model/Project.rb', line 158 def setOwnerName(ownerName) @ownerName = ownerName end |
#setStatus(status) ⇒ Object
- Set the status of the project.
Parameters
- * status
- Status of the project.
58 59 60 |
# File 'lib/projects/model/Project.rb', line 58 def setStatus(status) @status = status end |
#setStatusURL(statusUrl) ⇒ Object
- Set the status URL.
Parameters
- * statusUrl
- URL for the status.
458 459 460 |
# File 'lib/projects/model/Project.rb', line 458 def setStatusURL(statusUrl) @statusUrl = statusUrl end |
#setTasklistURL(tasklistUrl) ⇒ Object
- Set the task list URL.
Parameters
- * tasklistUrl
- URL for the task list.
378 379 380 |
# File 'lib/projects/model/Project.rb', line 378 def setTasklistURL(tasklistUrl) @tasklistUrl = tasklistUrl end |
#setTaskURL(taskUrl) ⇒ Object
- Set the task URL.
Parameters
- * taskUrl
- URL for the task.
398 399 400 |
# File 'lib/projects/model/Project.rb', line 398 def setTaskURL(taskUrl) @taskUrl = taskUrl end |
#setTimesheetURL(timesheetUrl) ⇒ Object
- Set the time sheet URL.
Parameters
- * timesheetUrl
- URL for the time sheet.
438 439 440 |
# File 'lib/projects/model/Project.rb', line 438 def setTimesheetURL(timesheetUrl) @timesheetUrl = timesheetUrl end |
#setURL(url) ⇒ Object
- Set the project URL.
Parameters
- * url
- URL for the project.
318 319 320 |
# File 'lib/projects/model/Project.rb', line 318 def setURL(url) @url = url end |
#setUserURL(userUrl) ⇒ Object
- Set the user URL.
Parameters
- * userUrl
- URL for the user.
558 559 560 |
# File 'lib/projects/model/Project.rb', line 558 def setUserURL(userUrl) @userUrl = userUrl end |
#toParamMAP ⇒ Object
- Convert the Project object into HashMap.
Returns
- HashMap object.
578 579 580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/projects/model/Project.rb', line 578 def toParamMAP requestBody = Hash.new if name != nil requestBody["name"] = name end if description != nil requestBody["description"] = description end if status != nil requestBody["status"] = status end return requestBody end |