Class: Projects::Model::Project
- Inherits:
-
Object
- Object
- Projects::Model::Project
- Defined in:
- lib/projects/model/Project.rb
Overview
- This class is used to make an object for Project.
Instance Method Summary collapse
-
#getActivityURL ⇒ Object
- Get the activity URL.
-
#getBugURL ⇒ Object
- Get the bug URL.
-
#getClosedBugCount ⇒ Object
- Get the closed bug count.
-
#getClosedMilestoneCount ⇒ Object
- Get the closed milestone count.
-
#getClosedTaskCount ⇒ Object
- Get the closed task count.
-
#getCreatedDate ⇒ Object
- Get the project created date.
-
#getCreatedDateFormat ⇒ Object
- Get the created date format for the project.
-
#getCreatedDateLong ⇒ Object
- Get the project created date long.
-
#getDescription ⇒ Object
- Get the project description.
-
#getDocumentURL ⇒ Object
- Get the document URL.
-
#getEventURL ⇒ Object
- Get the event URL.
-
#getFolderURL ⇒ Object
- Get the folder URL.
-
#getForumURL ⇒ Object
- Get the forum URL.
-
#getId ⇒ Object
- Get the project id.
-
#getIdString ⇒ Object
- Get the project id string.
-
#getMilestoneURL ⇒ Object
- Get the milestone URL.
-
#getName ⇒ Object
- Get the project name.
-
#getOpenBugCount ⇒ Object
- Get the open bug count.
-
#getOpenMilestoneCount ⇒ Object
- Get the open milestone count.
-
#getOpenTaskCount ⇒ Object
- Get the open task count.
-
#getOwnerId ⇒ Object
- Get the owner id.
-
#getOwnerName ⇒ Object
- Get the owner name.
-
#getStatus ⇒ Object
- Get the project status.
-
#getStatusURL ⇒ Object
- Get the status URL.
-
#getTasklistURL ⇒ Object
- Get the task list URL.
-
#getTaskURL ⇒ Object
- Get the task URL.
-
#getTemplateId ⇒ Object
- Get the template id of the project.
-
#getTimesheetURL ⇒ Object
- Get the time sheet URL.
-
#getURL ⇒ Object
- Get the project URL.
-
#getUserURL ⇒ Object
- Get the user URL.
-
#setActivityURL(activityUrl) ⇒ Object
- Set the activity URL.
-
#setBugURL(bugUrl) ⇒ Object
- Set the bug URL.
-
#setClosedBugCount(closedBugCount) ⇒ Object
- Set the closed bug count.
-
#setClosedMilestoneCount(closedMilestoneCount) ⇒ Object
- Set the closed milestone count.
-
#setClosedTaskCount(closedTaskCount) ⇒ Object
- Set the closed task count.
-
#setCreatedDate(createdDate) ⇒ Object
- Set the date when the project is being created.
-
#setCreatedDateFormat(createdDateFormat) ⇒ Object
- Set the created date format for the project.
-
#setCreatedDateLong(createdDateLong) ⇒ Object
- Set the project created date.
-
#setDescription(description) ⇒ Object
- Set the project description.
-
#setDocumentURL(documentUrl) ⇒ Object
- Set the document URL.
-
#setEventURL(eventUrl) ⇒ Object
- Set the event URL.
-
#setFolderURL(folderUrl) ⇒ Object
- Set the folder URL.
-
#setForumURL(forumUrl) ⇒ Object
- Set the forum URL.
-
#setId(id) ⇒ Object
- Set the project id.
-
#setIdString(idString) ⇒ Object
- Set the project id string.
-
#setMilestoneURL(milestoneUrl) ⇒ Object
- Set the milestone URL.
-
#setName(name) ⇒ Object
- Set the project name.
-
#setOpenBugCount(openBugCount) ⇒ Object
- Set the open bug count.
-
#setOpenMilestoneCount(openMilestoneCount) ⇒ Object
- Set the open milestone count.
-
#setOpenTaskCount(openTaskCount) ⇒ Object
- Set the open task count.
-
#setOwnerId(ownerId) ⇒ Object
- Set the owner id.
-
#setOwnerName(ownerName) ⇒ Object
- Set the owner name.
-
#setStatus(status) ⇒ Object
- Set the status of the project.
-
#setStatusURL(statusUrl) ⇒ Object
- Set the status URL.
-
#setTasklistURL(tasklistUrl) ⇒ Object
- Set the task list URL.
-
#setTaskURL(taskUrl) ⇒ Object
- Set the task URL.
-
#setTemplateId(templateId) ⇒ Object
- Set the template id of the project.
-
#setTimesheetURL(timesheetUrl) ⇒ Object
- Set the time sheet URL.
-
#setURL(url) ⇒ Object
- Set the project URL.
-
#setUserURL(userUrl) ⇒ Object
- Set the user URL.
-
#toParamMAP ⇒ Object
- Convert the Project object into HashMap.
Instance Method Details
#getActivityURL ⇒ Object
- Get the activity URL.
Returns
- Activity URL.
397 398 399 |
# File 'lib/projects/model/Project.rb', line 397 def getActivityURL return @activityUrl end |
#getBugURL ⇒ Object
- Get the bug URL.
Returns
- bug URL.
477 478 479 |
# File 'lib/projects/model/Project.rb', line 477 def getBugURL return @bugUrl end |
#getClosedBugCount ⇒ Object
- Get the closed bug count.
Returns
- Closed bug count for the project.
357 358 359 |
# File 'lib/projects/model/Project.rb', line 357 def getClosedBugCount return @closedBugCount end |
#getClosedMilestoneCount ⇒ Object
- Get the closed milestone count.
Returns
- closed milestone count for the project.
317 318 319 |
# File 'lib/projects/model/Project.rb', line 317 def getClosedMilestoneCount return @closedMilestoneCount end |
#getClosedTaskCount ⇒ Object
- Get the closed task count.
Returns
- Closed task count for the project.
277 278 279 |
# File 'lib/projects/model/Project.rb', line 277 def getClosedTaskCount return @closedTaskCount end |
#getCreatedDate ⇒ Object
- Get the project created date.
Returns
- Project created date.
137 138 139 |
# File 'lib/projects/model/Project.rb', line 137 def getCreatedDate return @createdDate end |
#getCreatedDateFormat ⇒ Object
- Get the created date format for the project.
Returns
- Project created date format.
157 158 159 |
# File 'lib/projects/model/Project.rb', line 157 def getCreatedDateFormat return @createdDateFormat end |
#getCreatedDateLong ⇒ Object
- Get the project created date long.
Returns
- project created date long.
177 178 179 |
# File 'lib/projects/model/Project.rb', line 177 def getCreatedDateLong return @createdDateLong end |
#getDescription ⇒ Object
- Get the project description.
Returns
- Project description.
197 198 199 |
# File 'lib/projects/model/Project.rb', line 197 def getDescription return @description end |
#getDocumentURL ⇒ Object
- Get the document URL.
Returns
- Document URL.
557 558 559 |
# File 'lib/projects/model/Project.rb', line 557 def getDocumentURL return @documentUrl end |
#getEventURL ⇒ Object
- Get the event URL.
Returns
- Event URL.
537 538 539 |
# File 'lib/projects/model/Project.rb', line 537 def getEventURL return @eventUrl end |
#getFolderURL ⇒ Object
- Get the folder URL.
Returns
- Folder URL.
577 578 579 |
# File 'lib/projects/model/Project.rb', line 577 def getFolderURL return @folderUrl end |
#getForumURL ⇒ Object
- Get the forum URL.
Returns
- Forum URL.
597 598 599 |
# File 'lib/projects/model/Project.rb', line 597 def getForumURL return @forumUrl end |
#getId ⇒ Object
- Get the project id.
Returns
- Project id.
29 30 31 |
# File 'lib/projects/model/Project.rb', line 29 def getId return @id end |
#getIdString ⇒ Object
- Get the project id string.
Returns
- Returns the project id string.
51 52 53 54 55 |
# File 'lib/projects/model/Project.rb', line 51 def getIdString return @idString = idString end |
#getMilestoneURL ⇒ Object
- Get the milestone URL.
Returns
- milestone URL.
417 418 419 |
# File 'lib/projects/model/Project.rb', line 417 def getMilestoneURL return @milestoneUrl end |
#getName ⇒ Object
- Get the project name.
Returns
- Project name.
73 74 75 |
# File 'lib/projects/model/Project.rb', line 73 def getName return @name end |
#getOpenBugCount ⇒ Object
- Get the open bug count.
Returns
- Open bug count for the project.
337 338 339 |
# File 'lib/projects/model/Project.rb', line 337 def getOpenBugCount return @openBugCount end |
#getOpenMilestoneCount ⇒ Object
- Get the open milestone count.
Returns
- Open milestone count for the project.
297 298 299 |
# File 'lib/projects/model/Project.rb', line 297 def getOpenMilestoneCount return @openMilestoneCount end |
#getOpenTaskCount ⇒ Object
- Get the open task count.
Returns
- Open task count for the project.
257 258 259 |
# File 'lib/projects/model/Project.rb', line 257 def getOpenTaskCount return @openTaskCount end |
#getOwnerId ⇒ Object
- Get the owner id.
Returns
- Owner id.
237 238 239 |
# File 'lib/projects/model/Project.rb', line 237 def getOwnerId return @ownerId end |
#getOwnerName ⇒ Object
- Get the owner name.
Returns
- The owner name.
217 218 219 |
# File 'lib/projects/model/Project.rb', line 217 def getOwnerName return @ownerName end |
#getStatus ⇒ Object
- Get the project status.
Returns
- Project status.
117 118 119 |
# File 'lib/projects/model/Project.rb', line 117 def getStatus return @status end |
#getStatusURL ⇒ Object
- Get the status URL.
Returns
- Status URL.
517 518 519 |
# File 'lib/projects/model/Project.rb', line 517 def getStatusURL return @statusUrl end |
#getTasklistURL ⇒ Object
- Get the task list URL.
Returns
- Task list URL.
437 438 439 |
# File 'lib/projects/model/Project.rb', line 437 def getTasklistURL return @tasklistUrl end |
#getTaskURL ⇒ Object
- Get the task URL.
Returns
- task URL.
457 458 459 |
# File 'lib/projects/model/Project.rb', line 457 def getTaskURL return @taskUrl end |
#getTemplateId ⇒ Object
- Get the template id of the project.
Returns
- Returns the template id.
95 96 97 98 99 |
# File 'lib/projects/model/Project.rb', line 95 def getTemplateId return @templateId end |
#getTimesheetURL ⇒ Object
- Get the time sheet URL.
Returns
- Time sheet URL.
497 498 499 |
# File 'lib/projects/model/Project.rb', line 497 def getTimesheetURL return @timesheetUrl end |
#getURL ⇒ Object
- Get the project URL.
Returns
- Project URL.
377 378 379 |
# File 'lib/projects/model/Project.rb', line 377 def getURL return @url end |
#getUserURL ⇒ Object
- Get the user URL.
Returns
- user URL.
617 618 619 |
# File 'lib/projects/model/Project.rb', line 617 def getUserURL return @userUrl end |
#setActivityURL(activityUrl) ⇒ Object
- Set the activity URL.
Parameters
- * activityUrl
- URL for the activity.
387 388 389 |
# File 'lib/projects/model/Project.rb', line 387 def setActivityURL(activityUrl) @activityUrl = activityUrl end |
#setBugURL(bugUrl) ⇒ Object
- Set the bug URL.
Parameters
- * bugUrl
- URL for the bug.
467 468 469 |
# File 'lib/projects/model/Project.rb', line 467 def setBugURL(bugUrl) @bugUrl = bugUrl end |
#setClosedBugCount(closedBugCount) ⇒ Object
- Set the closed bug count.
Parameters
- * closedBugCount
- Closed bug count for the project.
347 348 349 |
# File 'lib/projects/model/Project.rb', line 347 def setClosedBugCount(closedBugCount) @closedBugCount = closedBugCount end |
#setClosedMilestoneCount(closedMilestoneCount) ⇒ Object
- Set the closed milestone count.
Parameters
- * closedMilestoneCount
- Closed milestone count for the project.
307 308 309 |
# File 'lib/projects/model/Project.rb', line 307 def setClosedMilestoneCount(closedMilestoneCount) @closedMilestoneCount = closedMilestoneCount end |
#setClosedTaskCount(closedTaskCount) ⇒ Object
- Set the closed task count.
Parameters
- * closedTaskCount
- Closed task count for the project.
267 268 269 |
# File 'lib/projects/model/Project.rb', line 267 def setClosedTaskCount(closedTaskCount) @closedTaskCount = closedTaskCount end |
#setCreatedDate(createdDate) ⇒ Object
- Set the date when the project is being created.
Parameters
- * createdDate
- Created date for the project.
127 128 129 |
# File 'lib/projects/model/Project.rb', line 127 def setCreatedDate(createdDate) @createdDate = createdDate end |
#setCreatedDateFormat(createdDateFormat) ⇒ Object
- Set the created date format for the project.
Parameters
- * createdDate
- Project created date format.
147 148 149 |
# File 'lib/projects/model/Project.rb', line 147 def setCreatedDateFormat(createdDateFormat) @createdDateFormat = createdDateFormat end |
#setCreatedDateLong(createdDateLong) ⇒ Object
- Set the project created date.
Parameters
- * createdDateLong
- Project created date.
167 168 169 |
# File 'lib/projects/model/Project.rb', line 167 def setCreatedDateLong(createdDateLong) @createdDateLong = createdDateLong end |
#setDescription(description) ⇒ Object
- Set the project description.
Parameters
- * description
- Description of the project.
187 188 189 |
# File 'lib/projects/model/Project.rb', line 187 def setDescription(description) @description = description end |
#setDocumentURL(documentUrl) ⇒ Object
- Set the document URL.
Parameters
- * documentUrl
- URL for the document.
547 548 549 |
# File 'lib/projects/model/Project.rb', line 547 def setDocumentURL(documentUrl) @documentUrl = documentUrl end |
#setEventURL(eventUrl) ⇒ Object
- Set the event URL.
Parameters
- * eventUrl
- URL for the event.
527 528 529 |
# File 'lib/projects/model/Project.rb', line 527 def setEventURL(eventUrl) @eventUrl = eventUrl end |
#setFolderURL(folderUrl) ⇒ Object
- Set the folder URL.
Parameters
- * folderUrl
- URL for the folder.
567 568 569 |
# File 'lib/projects/model/Project.rb', line 567 def setFolderURL(folderUrl) @folderUrl = folderUrl end |
#setForumURL(forumUrl) ⇒ Object
- Set the forum URL.
Parameters
- * forumUrl
- URL for the forum.
587 588 589 |
# File 'lib/projects/model/Project.rb', line 587 def setForumURL(forumUrl) @forumUrl = forumUrl end |
#setId(id) ⇒ Object
- Set the project id.
Parameters
- * id
- ID of the project.
19 20 21 |
# File 'lib/projects/model/Project.rb', line 19 def setId(id) @id = id end |
#setIdString(idString) ⇒ Object
- Set the project id string.
Parameters
- * idString
- Project id string.
39 40 41 42 43 |
# File 'lib/projects/model/Project.rb', line 39 def setIdString(idString) @idString = idString end |
#setMilestoneURL(milestoneUrl) ⇒ Object
- Set the milestone URL.
Parameters
- * milestoneUrl
- URL for the milestone.
407 408 409 |
# File 'lib/projects/model/Project.rb', line 407 def setMilestoneURL(milestoneUrl) @milestoneUrl = milestoneUrl end |
#setName(name) ⇒ Object
- Set the project name.
Parameters
- * name
- Name of the project.
63 64 65 |
# File 'lib/projects/model/Project.rb', line 63 def setName(name) @name = name end |
#setOpenBugCount(openBugCount) ⇒ Object
- Set the open bug count.
Parameters
- * openBugCount
- Open bug count for the project.
327 328 329 |
# File 'lib/projects/model/Project.rb', line 327 def setOpenBugCount(openBugCount) @openBugCount = openBugCount end |
#setOpenMilestoneCount(openMilestoneCount) ⇒ Object
- Set the open milestone count.
Parameters
- * openMilestoneCount
- Open milestone count for the project.
287 288 289 |
# File 'lib/projects/model/Project.rb', line 287 def setOpenMilestoneCount(openMilestoneCount) @openMilestoneCount = openMilestoneCount end |
#setOpenTaskCount(openTaskCount) ⇒ Object
- Set the open task count.
Parameters
- * openTaskCount
- Open task count for the project.
247 248 249 |
# File 'lib/projects/model/Project.rb', line 247 def setOpenTaskCount(openTaskCount) @openTaskCount = openTaskCount end |
#setOwnerId(ownerId) ⇒ Object
- Set the owner id.
Parameters
- * ownerId
- ID of the owner.
227 228 229 |
# File 'lib/projects/model/Project.rb', line 227 def setOwnerId(ownerId) @ownerId = ownerId end |
#setOwnerName(ownerName) ⇒ Object
- Set the owner name.
Parameters
- * ownerName
- Name of the owner.
207 208 209 |
# File 'lib/projects/model/Project.rb', line 207 def setOwnerName(ownerName) @ownerName = ownerName end |
#setStatus(status) ⇒ Object
- Set the status of the project.
Parameters
- * status
- Status of the project.
107 108 109 |
# File 'lib/projects/model/Project.rb', line 107 def setStatus(status) @status = status end |
#setStatusURL(statusUrl) ⇒ Object
- Set the status URL.
Parameters
- * statusUrl
- URL for the status.
507 508 509 |
# File 'lib/projects/model/Project.rb', line 507 def setStatusURL(statusUrl) @statusUrl = statusUrl end |
#setTasklistURL(tasklistUrl) ⇒ Object
- Set the task list URL.
Parameters
- * tasklistUrl
- URL for the task list.
427 428 429 |
# File 'lib/projects/model/Project.rb', line 427 def setTasklistURL(tasklistUrl) @tasklistUrl = tasklistUrl end |
#setTaskURL(taskUrl) ⇒ Object
- Set the task URL.
Parameters
- * taskUrl
- URL for the task.
447 448 449 |
# File 'lib/projects/model/Project.rb', line 447 def setTaskURL(taskUrl) @taskUrl = taskUrl end |
#setTemplateId(templateId) ⇒ Object
- Set the template id of the project.
Parameters
- * templateId
- ID of the template.
83 84 85 86 87 |
# File 'lib/projects/model/Project.rb', line 83 def setTemplateId(templateId) @templateId = templateId end |
#setTimesheetURL(timesheetUrl) ⇒ Object
- Set the time sheet URL.
Parameters
- * timesheetUrl
- URL for the time sheet.
487 488 489 |
# File 'lib/projects/model/Project.rb', line 487 def setTimesheetURL(timesheetUrl) @timesheetUrl = timesheetUrl end |
#setURL(url) ⇒ Object
- Set the project URL.
Parameters
- * url
- URL for the project.
367 368 369 |
# File 'lib/projects/model/Project.rb', line 367 def setURL(url) @url = url end |
#setUserURL(userUrl) ⇒ Object
- Set the user URL.
Parameters
- * userUrl
- URL for the user.
607 608 609 |
# File 'lib/projects/model/Project.rb', line 607 def setUserURL(userUrl) @userUrl = userUrl end |
#toParamMAP ⇒ Object
- Convert the Project object into HashMap.
Returns
- HashMap object.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/projects/model/Project.rb', line 627 def toParamMAP requestBody = Hash.new if name != nil requestBody["name"] = name end if description != nil requestBody["description"] = description end if status != nil requestBody["status"] = status end if templateId != nil requestBody["template_id"] = templateId end return requestBody end |